==> ug_gemeinde-1.3.4-py3-none-any.whl: ug_gemeinde/GemeindeInstall.sh <==
#!/bin/bash

##  GemeindeInstall.sh
##  
##  Diese Datei wird dem User gegeben, damit er damit die Gemeinde-GUI auf einem Linux-Rechner
##  einfach installieren kann.
##
##  Als Anleitung werden ihm folgende Schritte nahegelegt:
##      1. Ordner/Verzeichnis für die GUI anlegen.
##      2. Das Skript GemeindeInstall.sh in dieses Verzeichnis speichern.
##      3. Das Skript in diesem Verzeichnis ausführen, d.h.
##         entweder   a) Terminal öffnen
##                    b) Mit cd in das neue Verzeichnis wechseln
##                    c) Nötigenfalls das Skrpt ausführbar machen
##                    d) Dort das Skript ausführen (./GemeindeInstall.sh)
##         oder       a) Das Skript im Dateimanager anklicken
##      4. Prüfen, ob die Installation erfolgreich war: In dem Verzeichnis müssen 
##         mindestens folgende Dateien erschienen sein:
##              Gemeinde.yaml
##              Icons.yaml
##              GemeindeStart.sh
##              GemeindeUpgrade.sh
##      5. Damit die GUI bzw. das Upgrade bequem gestartet werden kann, sollte in
##         einem Panel oder auf dem Schreibtisch je ein Starter für GemeindeStart.sh
##         und GemeindeUpgrade.sh eingerichtet werden. In beiden Startern sollte
##         "Im Terminal ausführen" aktiviert werden.
##      6. Optional: Um den Programmstart bzw. das dann folgende Login zu erleichtern,
##         kann in dem Skript GemeindeStart.sh die Zeile
##              python -m ug_gemeinde.Gemeinde
##         ersetzt werden durch
##              python -m ug_gemeinde.Gemeinde -u username -p password
##         Diese beiden Werte werden dann nach dem Start der GUI automatisch in die
##         entsprechenden Felder übernommen; es braucht nur noch der Login-Button
##         gedrückt zu werden.
##         WARNUNG: Diese Ergänzung sollte nur erfolgen, wenn der Rechner gut
##                  geschützt ist vor Fremdbenutzung usw., weil Username und Passwort
##                  im Klartext gespeichert werden.

##  Virtuelle Umgebung herstellen
echo "Virtuelle Umgebung herstellen"
python3 -m venv .venv

##  Virtuelle Umgebung aktivieren
echo "Virtuelle Umgebung aktivieren"
. .venv/bin/activate

##  GUI Gemeinde installieren
echo "GUI Gemeinde installieren"
pip install ug_gemeinde

##  GUI im Setup-Modus aufrufen.
##  Damit wird von der GUI ein Setup ausgefürhrt, dass folgendes erledigt und dann stoppt:
##      1. Gemeinde.yaml und Icons.yaml ins aktuelle Verzeichnis kopiert
##      2. Upgrade-Skript GemeindeUpgrade.sh ins aktuelle Verzeichnis kopiert
##      3. Start-Skript GemeindeStart.sh ins aktuelle Verzeichnis kopiert
##      4. Die beiden neuen Skripte ausführbar machen
echo "GUI im Setup-Modus aufrufen"
python -m ug_gemeinde.Gemeinde --setup
chmod a+x GemeindeStart.sh GemeindeUpgrade.sh

##  Virtuelle Umgebung deaktivieren
deactivate

==> ug_gemeinde-1.3.7-py3-none-any.whl: ug_gemeinde/GemeindeInstall.sh <==
#!/bin/bash

##  GemeindeInstall.sh
##  
##  Diese Datei wird dem User gegeben, damit er damit die Gemeinde-GUI auf einem Linux-Rechner
##  einfach installieren kann.
##
##  Als Anleitung werden ihm folgende Schritte nahegelegt:
##      1. Ordner/Verzeichnis für die GUI anlegen.
##      2. Das Skript GemeindeInstall.sh in dieses Verzeichnis speichern.
##      3. Das Skript in diesem Verzeichnis ausführen, d.h.
##         entweder   a) Terminal öffnen
##                    b) Mit cd in das neue Verzeichnis wechseln
##                    c) Nötigenfalls das Skrpt ausführbar machen
##                    d) Dort das Skript ausführen (./GemeindeInstall.sh)
##         oder       a) Das Skript im Dateimanager anklicken
##      4. Prüfen, ob die Installation erfolgreich war: In dem Verzeichnis müssen 
##         mindestens folgende Dateien erschienen sein:
##              Gemeinde.yaml
##              Icons.yaml
##              GemeindeStart.sh
##              GemeindeUpgrade.sh
##      5. Damit die GUI bzw. das Upgrade bequem gestartet werden kann, sollte in
##         einem Panel oder auf dem Schreibtisch je ein Starter für GemeindeStart.sh
##         und GemeindeUpgrade.sh eingerichtet werden. In beiden Startern sollte
##         "Im Terminal ausführen" aktiviert werden.
##      6. Optional: Um den Programmstart bzw. das dann folgende Login zu erleichtern,
##         kann in dem Skript GemeindeStart.sh die Zeile
##              python -m ug_gemeinde.Gemeinde
##         ersetzt werden durch
##              python -m ug_gemeinde.Gemeinde -u username -p password
##         Diese beiden Werte werden dann nach dem Start der GUI automatisch in die
##         entsprechenden Felder übernommen; es braucht nur noch der Login-Button
##         gedrückt zu werden.
##         WARNUNG: Diese Ergänzung sollte nur erfolgen, wenn der Rechner gut
##                  geschützt ist vor Fremdbenutzung usw., weil Username und Passwort
##                  im Klartext gespeichert werden.

##  Virtuelle Umgebung herstellen
echo "Virtuelle Umgebung herstellen"
python3 -m venv .venv

##  Virtuelle Umgebung aktivieren
echo "Virtuelle Umgebung aktivieren"
source .venv/bin/activate

##  GUI Gemeinde installieren
echo "GUI Gemeinde installieren"
pip cache purge
pip install --no-cache-dir ug_gemeinde

##  GUI im Setup-Modus aufrufen.
##  Damit wird von der GUI ein Setup ausgefürhrt, dass folgendes erledigt und dann stoppt:
##      1. Gemeinde.yaml und Icons.yaml ins aktuelle Verzeichnis kopiert
##      2. Upgrade-Skript GemeindeUpgrade.sh ins aktuelle Verzeichnis kopiert
##      3. Start-Skript GemeindeStart.sh ins aktuelle Verzeichnis kopiert
##      4. Die beiden neuen Skripte ausführbar machen
echo "GUI im Setup-Modus aufrufen"
python -m ug_gemeinde.Gemeinde --setup
chmod a+x GemeindeStart.sh GemeindeUpgrade.sh

##  Virtuelle Umgebung deaktivieren
deactivate
